@@ -1,4 +1,4 @@
-from typing import Sequence, Type, Union
+from typing import Sequence, Union
 
 import jax.experimental.host_callback as hcb
 import jax.lax as lax
@@ -10,7 +10,6 @@ from .unvmap import unvmap_any
 def error_if(
     pred: Union[bool, Array[..., bool]],
     msg: str,
-    error_cls: Type[Exception] = ValueError,
 ) -> bool:
     """For use as part of validating inputs.
     Works even under JIT.
@@ -22,17 +21,16 @@ def error_if(
 
         f(jax.numpy.array(-1))
     """
-    branched_error_if(pred, 0, [msg], error_cls)
+    branched_error_if(pred, 0, [msg])
 
 
 def branched_error_if(
     pred: Union[bool, Array[..., bool]],
     index: Int,
     msgs: Sequence[str],
-    error_cls: Type[Exception] = ValueError,
 ) -> bool:
     def raises(_index):
-        raise error_cls(msgs[_index.item()])
+        raise RuntimeError(msgs[_index.item()])
 
     pred = unvmap_any(pred)
     lax.cond(pred, lambda: hcb.call(raises, index), lambda: None)
