@@ -21,6 +21,9 @@ class Bosh3(AbstractERK):
 
     3rd order explicit Runge--Kutta method. Has an embedded 2nd order method for
     adaptive step sizing.
+
+    Also sometimes known as "Heun's third order method". (Not to be confused with
+    [`diffrax.Heun`][], which is a second order method).
     """
 
     tableau = _bosh3_tableau
