@@ -1,6 +1,6 @@
 from typing import Tuple
 
-import jax
+import jax.tree_util as jtu
 
 from ..custom_types import Bool, DenseInfo, PyTree, Scalar
 from ..local_interpolation import LocalLinearInterpolation
@@ -26,7 +26,7 @@ class ImplicitEuler(AbstractImplicitSolver):
     A-B-L stable 1st order SDIRK method. Does not support adaptive step sizing.
     """
 
-    term_structure = jax.tree_structure(0)
+    term_structure = jtu.tree_structure(0)
     interpolation_cls = LocalLinearInterpolation
 
     def order(self, terms):
@@ -56,11 +56,11 @@ class ImplicitEuler(AbstractImplicitSolver):
         dense_info = dict(y0=y0, y1=y1)
         return y1, None, dense_info, None, nonlinear_sol.result
 
-    def func_for_init(
+    def func(
         self,
         terms: AbstractTerm,
         t0: Scalar,
         y0: PyTree,
         args: PyTree,
     ) -> PyTree:
-        return terms.func_for_init(t0, y0, args)
+        return terms.vf(t0, y0, args)
