@@ -5,6 +5,7 @@ import equinox as eqx
 import jax
 import jax.lax as lax
 import jax.numpy as jnp
+import jax.tree_util as jtu
 
 from ..custom_types import Array, Bool, PyTree, Scalar
 from ..misc import nextafter, prevbefore, rms_norm, ω
@@ -19,13 +20,13 @@ def _select_initial_step(
     t0: Scalar,
     y0: PyTree,
     args: PyTree,
-    func_for_init: Callable[[Scalar, PyTree, PyTree], PyTree],
+    func: Callable[[Scalar, PyTree, PyTree], PyTree],
     error_order: Scalar,
     rtol: Scalar,
     atol: Scalar,
     norm: Callable[[PyTree], Scalar],
 ) -> Scalar:
-    f0 = func_for_init(terms, t0, y0, args)
+    f0 = func(terms, t0, y0, args)
     scale = (atol + ω(y0).call(jnp.abs) * rtol).ω
     d0 = norm((y0**ω / scale**ω).ω)
     d1 = norm((f0**ω / scale**ω).ω)
@@ -36,7 +37,7 @@ def _select_initial_step(
 
     t1 = t0 + h0
     y1 = (y0**ω + h0 * f0**ω).ω
-    f1 = func_for_init(terms, t1, y1, args)
+    f1 = func(terms, t1, y1, args)
     d2 = norm(((f1**ω - f0**ω) / scale**ω).ω) / h0
 
     max_d = jnp.maximum(d1, d2)
@@ -61,6 +62,14 @@ class _gendocs_norm:
 
 
 class AbstractAdaptiveStepSizeController(AbstractStepSizeController):
+    """Indicates an adaptive step size controller.
+
+    Accepts tolerances `rtol` and `atol`. When used in conjunction with an implicit
+    solver ([`diffrax.AbstractImplicitSolver`][]), then these tolerances will
+    automatically be used as the tolerances for the nonlinear solver passed to the
+    implicit solver, if they are not specified manually.
+    """
+
     rtol: Optional[Scalar] = None
     atol: Optional[Scalar] = None
 
@@ -297,7 +306,7 @@ class PIDController(AbstractAdaptiveStepSizeController):
         y0: PyTree,
         dt0: Optional[Scalar],
         args: PyTree,
-        func_for_init: Callable[[Scalar, PyTree, PyTree], PyTree],
+        func: Callable[[Scalar, PyTree, PyTree], PyTree],
         error_order: Optional[Scalar],
     ) -> Tuple[Scalar, _ControllerState]:
         del t1
@@ -308,7 +317,7 @@ class PIDController(AbstractAdaptiveStepSizeController):
                 t0,
                 y0,
                 args,
-                func_for_init,
+                func,
                 error_order,
                 self.rtol,
                 self.atol,
@@ -383,14 +392,9 @@ class PIDController(AbstractAdaptiveStepSizeController):
         # `scaled_error = norm(y_error) / (atol + norm(y) * rtol)`  (2)
         # We do (1). torchdiffeq and torchsde do (1). Soderlind's papers and
         # OrdinaryDiffEq.jl do (2).
-        # We choose to do (1) by considering what were to happen if we were to increase
-        # the dimensionality of `y` and `y_error` with zeros. (i.e. append as many
-        # `dy/dt=0` problems as we please, and then solve them perfectly) Assuming that
-        # `norm` normalises by the number of dimensions (e.g. like an RMS norm) then
-        # (2) will see `norm(y_error) -> 0`, `norm(y) -> 0`, and therefore `atol`
-        # playing a larger and larger role. In contrast (2) simply scales things down
-        # without `atol` taking on extra importance. (This is quite thin justification
-        # though.)
+        # We choose to do (1) by considering what if `y` were to contain different
+        # components at very different scales. The errors in the small components may
+        # be drowned out by the errors in the big components if we were using (2).
         #
         # Some will put the multiplication by `safety` outside the `coeff/error_order`
         # exponent. (1) Some will put it inside. (2)
@@ -462,7 +466,7 @@ class PIDController(AbstractAdaptiveStepSizeController):
             _y = jnp.maximum(jnp.abs(_y0), jnp.abs(_y1_candidate))
             return _y_error / (self.atol + _y * self.rtol)
 
-        scaled_error = self.norm(jax.tree_map(_scale, y0, y1_candidate, y_error))
+        scaled_error = self.norm(jtu.tree_map(_scale, y0, y1_candidate, y_error))
         keep_step = scaled_error < 1
         if self.dtmin is not None:
             keep_step = keep_step | at_dtmin
